// ModuleIo.h
//
// Board-specific module operations

#ifndef ModuleIoH
#define ModuleIoH

#include <X3_SD16_Mb.h>
#include <Ficl/FiclSystem_Mb.h>
#include <BinView_Mb.h>

//===========================================================================
//  Information Functions
//===========================================================================
//  NOTE - these are often used in constructors so cannot depend on objects
//         without due care taken
//
//   General Info
inline std::string ModuleNameStr()
            {  return  "X3-SD16";  }
inline unsigned int    NumberOfAlerts()
            {  return 9;  }
//
//   Analog In Info
inline unsigned int    AnalogInRanges()
          {  return 3;  }
inline unsigned int    AnalogInChannels()
          {  return 16;  }
inline float  MaxInRateMHz()
          {  return 0.144f;  }     // In MHz

//
//   Analog Out Info

inline int    AnalogOutChannels()
        {  return 16;  }

//
//   Application Feature Presence  -- used to hide GUI Portions

inline bool   HasClockMux()
        {  return true; }
inline bool   HasProgrammableReference()
        {  return true; }
inline bool   HasTestModeControl()
        {  return false; }
inline bool   HasSync()
        {  return true; }
inline bool   HasFiclSupport()
        {  return true; }
inline bool   HasRangeGrid()
        {  return true; }


typedef std::vector<std::string> StringArray;
StringArray  TestModeStrings();

//===========================================================================
//  CLASS ModuleIo  -- Hardware Access and Application Io Class
//===========================================================================

class ModuleIo
{
public:
    typedef Innovative::X3_SD16 ModuleType;
    typedef Innovative::X3_SD16::Timebase Timebase;

    ModuleIo();
    ~ModuleIo();

    //  Module Aliases
    Innovative::X3_SD16 & operator() ()
        {  return Module;  }
    Innovative::X3_SD16 & Ref()
        {  return Module;  }
    Innovative::IFiclTarget *  FiclTarget()
            {   return &Module;  }

    //version
    std::string SoftwareVersionString()
    { return std::string("2.0.0"); }

    //
    //  App System Methods
    void  FiclConnectTo(Innovative::FiclSystem & ficl);
    std::string Help() const;

    //
    //  Module Methods
    void  AfterOpen();
    void  Configure(Innovative::BinView & hs, Innovative::BinView & ls);
    void  SetInputSoftwareTrigger(bool state);
    void  SetOutputSoftwareTrigger(bool state);
    void  SetTestConfiguration( bool enable, int mode_idx );

protected:

private:
	Innovative::X3_SD16  Module;
};
#endif
